==> react-molecule-photo-uploader-2.29.0.tgz: package/lib/ThumbCard/index.js <==
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomIcon, { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { ACTION_THUMB_CARD_CLASS_NAME, BUTTON_THUMB_CARD_CLASS_NAME, CONTAINER_THUMB_CARD_CLASS_NAME, ICON_THUMB_CARD_CLASS_NAME, IMAGE_THUMB_CARD_CLASS_NAME, THUMB_CARD_CLASS_NAME } from './config.js';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
var ThumbCard = function ThumbCard(_ref) {
  var _cx, _cx2;
  var _ref$iconSize = _ref.iconSize,
    iconSize = _ref$iconSize === void 0 ? ATOM_ICON_SIZES.small : _ref$iconSize,
    callbackDeleteItem = _ref.callbackDeleteItem,
    callbackRetryUpload = _ref.callbackRetryUpload,
    callbackRotateItem = _ref.callbackRotateItem,
    _ref$content = _ref.content,
    Content = _ref$content === void 0 ? function () {
      return null;
    } : _ref$content,
    deleteIcon = _ref.deleteIcon,
    index = _ref.index,
    image = _ref.image,
    mainPhotoLabel = _ref.mainPhotoLabel,
    outputImageAspectRatioDisabled = _ref.outputImageAspectRatioDisabled,
    rejectPhotosIcon = _ref.rejectPhotosIcon,
    retryIcon = _ref.retryIcon,
    rotateIcon = _ref.rotateIcon;
  var hasErrors = image.hasErrors;
  var counterClass = cx(THUMB_CARD_CLASS_NAME + "-counter", (_cx = {}, _cx[THUMB_CARD_CLASS_NAME + "-mainCounter"] = index === 0, _cx));
  var imageThumbClass = cx(IMAGE_THUMB_CARD_CLASS_NAME, (_cx2 = {}, _cx2[IMAGE_THUMB_CARD_CLASS_NAME + "--ratioDisabled"] = outputImageAspectRatioDisabled, _cx2));
  return /*#__PURE__*/_jsxs("div", {
    className: THUMB_CARD_CLASS_NAME,
    children: [/*#__PURE__*/_jsx("div", {
      className: counterClass,
      children: index === 0 ? mainPhotoLabel : index + 1
    }), /*#__PURE__*/_jsx("div", {
      className: CONTAINER_THUMB_CARD_CLASS_NAME,
      children: hasErrors ? /*#__PURE__*/_jsx("div", {
        className: "" + ICON_THUMB_CARD_CLASS_NAME,
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: ATOM_ICON_SIZES.extraLarge,
          children: rejectPhotosIcon
        })
      }) : /*#__PURE__*/_jsx("img", {
        src: image.preview,
        className: imageThumbClass
      })
    }), /*#__PURE__*/_jsx(Content, {
      file: image,
      index: index
    }), /*#__PURE__*/_jsxs("div", {
      className: ACTION_THUMB_CARD_CLASS_NAME,
      children: [/*#__PURE__*/_jsx("div", {
        className: BUTTON_THUMB_CARD_CLASS_NAME,
        onClick: function onClick() {
          return callbackDeleteItem(index);
        },
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: iconSize,
          children: deleteIcon
        })
      }), hasErrors ? /*#__PURE__*/_jsx("div", {
        className: BUTTON_THUMB_CARD_CLASS_NAME,
        onClick: function onClick(e) {
          return callbackRetryUpload(index);
        },
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: iconSize,
          children: retryIcon
        })
      }) : /*#__PURE__*/_jsx("div", {
        className: BUTTON_THUMB_CARD_CLASS_NAME,
        onClick: function onClick(e) {
          return callbackRotateItem(index);
        },
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: iconSize,
          children: rotateIcon
        })
      })]
    })]
  });
};
ThumbCard.displayName = 'ThumbCard';
export default ThumbCard;

==> react-molecule-photo-uploader-2.30.0.tgz: package/lib/ThumbCard/index.js <==
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomIcon, { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { ACTION_THUMB_CARD_CLASS_NAME, BUTTON_THUMB_CARD_CLASS_NAME, CONTAINER_THUMB_CARD_CLASS_NAME, ICON_THUMB_CARD_CLASS_NAME, IMAGE_THUMB_CARD_CLASS_NAME, THUMB_CARD_CLASS_NAME } from './config.js';
import { DEFAULT_VIEW_TYPE, VIEW_TYPE } from './../config.js';
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
var ThumbCard = function ThumbCard(_ref) {
  var _cx, _cx2;
  var _ref$iconSize = _ref.iconSize,
    iconSize = _ref$iconSize === void 0 ? ATOM_ICON_SIZES.small : _ref$iconSize,
    callbackDeleteItem = _ref.callbackDeleteItem,
    callbackRetryUpload = _ref.callbackRetryUpload,
    callbackRotateItem = _ref.callbackRotateItem,
    _ref$content = _ref.content,
    Content = _ref$content === void 0 ? function () {
      return null;
    } : _ref$content,
    deleteIcon = _ref.deleteIcon,
    dragIcon = _ref.dragIcon,
    index = _ref.index,
    image = _ref.image,
    mainPhotoLabel = _ref.mainPhotoLabel,
    outputImageAspectRatioDisabled = _ref.outputImageAspectRatioDisabled,
    rejectPhotosIcon = _ref.rejectPhotosIcon,
    retryIcon = _ref.retryIcon,
    rotateIcon = _ref.rotateIcon,
    viewType = _ref.viewType;
  var hasErrors = image.hasErrors;
  var isDefaultView = viewType === DEFAULT_VIEW_TYPE;
  var isListtView = viewType === VIEW_TYPE.LIST;
  var counterClass = cx(THUMB_CARD_CLASS_NAME + "-counter", (_cx = {}, _cx[THUMB_CARD_CLASS_NAME + "-mainCounter"] = index === 0 && isDefaultView, _cx));
  var imageThumbClass = cx(IMAGE_THUMB_CARD_CLASS_NAME, (_cx2 = {}, _cx2[IMAGE_THUMB_CARD_CLASS_NAME + "--ratioDisabled"] = outputImageAspectRatioDisabled, _cx2));
  return /*#__PURE__*/_jsxs("div", {
    className: THUMB_CARD_CLASS_NAME,
    children: [/*#__PURE__*/_jsx("div", {
      className: counterClass,
      children: index === 0 && isDefaultView ? mainPhotoLabel : index + 1
    }), /*#__PURE__*/_jsx("div", {
      className: CONTAINER_THUMB_CARD_CLASS_NAME,
      children: hasErrors ? /*#__PURE__*/_jsx("div", {
        className: "" + ICON_THUMB_CARD_CLASS_NAME,
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: ATOM_ICON_SIZES.extraLarge,
          children: rejectPhotosIcon
        })
      }) : /*#__PURE__*/_jsxs(_Fragment, {
        children: [isListtView && /*#__PURE__*/_jsx(AtomIcon, {
          size: iconSize,
          children: dragIcon
        }), /*#__PURE__*/_jsx("img", {
          src: image.preview,
          className: imageThumbClass
        })]
      })
    }), /*#__PURE__*/_jsx(Content, {
      file: image,
      index: index
    }), /*#__PURE__*/_jsxs("div", {
      className: ACTION_THUMB_CARD_CLASS_NAME,
      children: [/*#__PURE__*/_jsx("div", {
        className: BUTTON_THUMB_CARD_CLASS_NAME,
        onClick: function onClick() {
          return callbackDeleteItem(index);
        },
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: iconSize,
          children: deleteIcon
        })
      }), hasErrors ? /*#__PURE__*/_jsx("div", {
        className: BUTTON_THUMB_CARD_CLASS_NAME,
        onClick: function onClick(e) {
          return callbackRetryUpload(index);
        },
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: iconSize,
          children: retryIcon
        })
      }) : /*#__PURE__*/_jsx("div", {
        className: BUTTON_THUMB_CARD_CLASS_NAME,
        onClick: function onClick(e) {
          return callbackRotateItem(index);
        },
        children: /*#__PURE__*/_jsx(AtomIcon, {
          size: iconSize,
          children: rotateIcon
        })
      })]
    })]
  });
};
ThumbCard.displayName = 'ThumbCard';
export default ThumbCard;
